@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiChrSheet.cpp,v 1.21 2009/05/14 08:33:26 bowkenken Exp $
+* $Id: GuiChrSheet.cpp,v 1.24 2009/06/01 06:29:57 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -166,9 +166,9 @@ void GuiChrSheet::newWinMisc()
 
 	// ̾
 
-	static char name[16 + MBR_NAME_MAX_LEN + 1];
-	sn_printf( name, 16 + CHR_NAME_MAX_LEN, "name : %*s",
-			MBR_NAME_MAX_LEN, " " );
+	static char name[16 + MBR_NAME_MAX_BYTE + 1];
+	sn_printf( name, 16 + MBR_NAME_MAX_BYTE, "name : %*s",
+			MBR_NAME_MAX_BYTE, " " );
 
 	mName = gtk_label_new( name );
 	if( mName == NULL ){
@@ -438,9 +438,9 @@ void GuiChrSheet::newWinStatTab()
 	gtk_widget_show( label );
 	x++;
 
-	static char str[RACE_STR_MAX_LEN + 1];
-	sn_printf( str, RACE_STR_MAX_LEN, "%*s",
-			RACE_STR_MAX_LEN, " " );
+	static char str[RACE_STR_MAX_BYTE + 1];
+	sn_printf( str, RACE_STR_MAX_BYTE, "%*s",
+			RACE_STR_MAX_BYTE, " " );
 	mStatRace = gtk_button_new_with_label( str );
 	if( mStatRace == NULL ){
 		print_msg( FLG_MSG_ERR, "gtk_button_new_with_label()" );
@@ -893,7 +893,7 @@ void GuiChrSheet::newWinAblTab()
 	GtkWidget *pTab;
 	long x, y;
 	GtkAttachOptions xOpt, yOpt;
-	static char str[SCREEN_WIDTH + 1];
+	static char str[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
 
 	// ֤Υ٥
 
@@ -917,8 +917,8 @@ void GuiChrSheet::newWinAblTab()
 
 	// 饹
 
-	sn_printf( str, CLASS_NAME_MAX_LEN, "%*s",
-			CLASS_NAME_MAX_LEN, " " );
+	sn_printf( str, CLASS_NAME_MAX_BYTE, "%*s",
+			CLASS_NAME_MAX_BYTE, " " );
 	mAblClass = gtk_button_new_with_label( str );
 	if( mAblClass == NULL ){
 		print_msg( FLG_MSG_ERR, "gtk_button_new_with_label()" );
@@ -1033,7 +1033,8 @@ void GuiChrSheet::newWinAblTab()
 
 		// ǽ̾
 
-		sn_printf( str, SCREEN_WIDTH, "%3s: ",
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%3s: ",
 				get_abl_name( (abl_kind_t)i ) );
 		label = gtk_label_new( str );
 		if( label == NULL ){
@@ -1052,7 +1053,8 @@ void GuiChrSheet::newWinAblTab()
 
 		// ٥
 
-		sn_printf( str, SCREEN_WIDTH, "%4s", " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%4s", " " );
 		mAblLev[i] = gtk_label_new( str );
 		if( mAblLev[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1070,7 +1072,8 @@ void GuiChrSheet::newWinAblTab()
 
 		// ٥뽤
 
-		sn_printf( str, SCREEN_WIDTH, "%6s", " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%6s", " " );
 		mAblAddLev[i] = gtk_label_new( str );
 		if( mAblAddLev[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1088,7 +1091,8 @@ void GuiChrSheet::newWinAblTab()
 
 		// и
 
-		sn_printf( str, SCREEN_WIDTH, "%10s", " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%10s", " " );
 		mAblExp[i] = gtk_label_new( str );
 		if( mAblExp[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1123,7 +1127,8 @@ void GuiChrSheet::newWinAblTab()
 
 		// ɬ׷и
 
-		sn_printf( str, SCREEN_WIDTH, "%10s", " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%10s", " " );
 		mAblNeedExp[i] = gtk_label_new( str );
 		if( mAblNeedExp[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1244,7 +1249,8 @@ void GuiChrSheet::newWinAblTab()
 
 		// ǽ̾
 
-		sn_printf( str, SCREEN_WIDTH, "%3s: ",
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%3s: ",
 				get_abl_name( (abl_kind_t)i ) );
 		label = gtk_label_new( str );
 		if( label == NULL ){
@@ -1263,7 +1269,8 @@ void GuiChrSheet::newWinAblTab()
 
 		// ٥
 
-		sn_printf( str, SCREEN_WIDTH, "%4s", " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%4s", " " );
 		mAblLev[i] = gtk_label_new( str );
 		if( mAblLev[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1281,7 +1288,8 @@ void GuiChrSheet::newWinAblTab()
 
 		// ٥뽤
 
-		sn_printf( str, SCREEN_WIDTH, "%6s", " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%6s", " " );
 		mAblAddLev[i] = gtk_label_new( str );
 		if( mAblAddLev[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1299,7 +1307,8 @@ void GuiChrSheet::newWinAblTab()
 
 		// и
 
-		sn_printf( str, SCREEN_WIDTH, "%10s", " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%10s", " " );
 		mAblExp[i] = gtk_label_new( str );
 		if( mAblExp[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1334,7 +1343,8 @@ void GuiChrSheet::newWinAblTab()
 
 		// ɬ׷и
 
-		sn_printf( str, SCREEN_WIDTH, "%10s", " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%10s", " " );
 		mAblNeedExp[i] = gtk_label_new( str );
 		if( mAblNeedExp[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1561,7 +1571,7 @@ void GuiChrSheet::newWinSkillTab( long page )
 	GtkWidget *pTab;
 	long x, y;
 	GtkAttachOptions xOpt, yOpt;
-	static char str[SCREEN_WIDTH + 1];
+	static char str[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
 
 	// ֤Υ٥
 
@@ -1588,8 +1598,8 @@ void GuiChrSheet::newWinSkillTab( long page )
 
 	// 饹
 
-	sn_printf( str, CLASS_NAME_MAX_LEN, "%*s",
-			CLASS_NAME_MAX_LEN, " " );
+	sn_printf( str, CLASS_NAME_MAX_BYTE, "%*s",
+			CLASS_NAME_MAX_BYTE, " " );
 	mSkillClass = gtk_button_new_with_label( str );
 	if( mSkillClass == NULL ){
 		print_msg( FLG_MSG_ERR, "gtk_button_new_with_label()" );
@@ -1704,8 +1714,9 @@ void GuiChrSheet::newWinSkillTab( long page )
 
 		long nSlot = page * SKILL_PER_PAGE_MAX_N + i;
 
-		sn_printf( str, SCREEN_WIDTH, "%*s",
-				SKILL_NAME_MAX_LEN, " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%*s",
+				SKILL_NAME_MAX_BYTE, " " );
 		mSkillName[page][i] = gtk_button_new_with_label( str );
 		if( mSkillName[page][i] == NULL ){
 			print_msg( FLG_MSG_ERR,
@@ -1729,7 +1740,8 @@ void GuiChrSheet::newWinSkillTab( long page )
 
 		// ٥
 
-		sn_printf( str, SCREEN_WIDTH, "%4s", " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%4s", " " );
 		mSkillLev[page][i] = gtk_label_new( str );
 		if( mSkillLev[page][i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1750,7 +1762,8 @@ void GuiChrSheet::newWinSkillTab( long page )
 
 		// и
 
-		sn_printf( str, SCREEN_WIDTH, "%10s", " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%10s", " " );
 		mSkillExp[page][i] = gtk_label_new( str );
 		if( mSkillExp[page][i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1791,7 +1804,8 @@ void GuiChrSheet::newWinSkillTab( long page )
 
 		// ɬ׷и
 
-		sn_printf( str, SCREEN_WIDTH, "%10s", " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%10s", " " );
 		mSkillNeedExp[page][i] = gtk_label_new( str );
 		if( mSkillNeedExp[page][i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1883,12 +1897,13 @@ void GuiChrSheet::newWinItemTab()
 
 	x = 0;
 	y = 0;
-	static char str[SCREEN_WIDTH + 1];
+	static char str[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
 	for( long i = 0; i < MBR_ITEM_MAX_N; i++ ){
 		x = 0;
 		y = i;
 
-		sn_printf( str, SCREEN_WIDTH, "%c)", 'A' + i );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%c)", 'A' + i );
 		label = gtk_label_new( str );
 		if( label == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1904,8 +1919,9 @@ void GuiChrSheet::newWinItemTab()
 		gtk_widget_show( label );
 		x++;
 
-		sn_printf( str, SCREEN_WIDTH, "%*s",
-				ITEM_NAME_MAX_LEN, " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%*s",
+				ITEM_NAME_MAX_BYTE, " " );
 		mItemName[i] = gtk_label_new( str );
 		if( mItemName[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -1966,14 +1982,15 @@ void GuiChrSheet::newWinEquipTab()
 
 	x = 0;
 	y = 0;
-	static char str[SCREEN_WIDTH + 1];
+	static char str[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
 	for( long i = 0; i < EQUIP_KIND_MAX_N; i++ ){
 		x = 0;
 		y = i;
 
 		// Ľ
 
-		sn_printf( str, SCREEN_WIDTH, "%s",
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%s",
 				get_item_equip_name( (equip_kind_t)i ) );
 		label = gtk_label_new( str );
 		if( label == NULL ){
@@ -2009,8 +2026,9 @@ void GuiChrSheet::newWinEquipTab()
 
 		// ̾
 
-		sn_printf( str, SCREEN_WIDTH, "%*s",
-				ITEM_NAME_MAX_LEN, " " );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%*s",
+				ITEM_NAME_MAX_BYTE, " " );
 		mEquipName[i] = gtk_label_new( str );
 		if( mEquipName[i] == NULL ){
 			print_msg( FLG_MSG_ERR, "gtk_label_new()" );
@@ -3047,11 +3065,12 @@ void GuiChrSheet::drawAbl( mbr_t *org, mbr_t *mbr )
 		abl_kind_t abl_kind = (abl_kind_t)i;
 		long mbr_lev_n = get_lev( mbr, abl_kind );
 		long mbr_lev_max = get_lev_max( mbr, abl_kind );
-		static char str[SCREEN_WIDTH + 1];
-		static char str_add_lev[SCREEN_WIDTH + 1];
+		static char str[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
+		static char str_add_lev[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
 
 		if( chk_modified_lev( mbr, abl_kind ) ){
-			sn_printf( str_add_lev, SCREEN_WIDTH,
+			sn_printf( str_add_lev,
+					SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
 					MSG_FMT_MBR_DATA_ADD_LEV,
 					mbr_lev_n - mbr_lev_max );
 		} else {
@@ -3060,7 +3079,8 @@ void GuiChrSheet::drawAbl( mbr_t *org, mbr_t *mbr )
 
 		// ٥
 
-		sn_printf( str, SCREEN_WIDTH, "%ld", mbr_lev_n );
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%ld", mbr_lev_n );
 		gtk_label_set_text( GTK_LABEL( mAblLev[i] ),
 				str );
 
@@ -3071,14 +3091,16 @@ void GuiChrSheet::drawAbl( mbr_t *org, mbr_t *mbr )
 
 		// и
 
-		sn_printf( str, SCREEN_WIDTH, "%ld",
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%ld",
 				mbr->abl.exp[abl_kind].n );
 		gtk_label_set_text( GTK_LABEL( mAblExp[i] ),
 				str );
 
 		// ɬ׷и
 
-		sn_printf( str, SCREEN_WIDTH, "%ld",
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%ld",
 				calc_need_exp( mbr_lev_n + 1, abl_kind ) );
 		gtk_label_set_text( GTK_LABEL( mAblNeedExp[i] ),
 				str );
@@ -3165,11 +3187,12 @@ void GuiChrSheet::drawSkill( mbr_t *org, mbr_t *mbr, long page )
 			mbr_need_exp = calc_need_exp( mbr_lev + 1,
 					abl_kind );
 		}
-		static char str[SCREEN_WIDTH + 1];
+		static char str[SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8 + 1];
 
 		// ̾
 
-		sn_printf( str, SCREEN_WIDTH, "%s",
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%s",
 				get_skill_name_from_kind( skill_kind ) );
 		set_label_text_button(
 				GTK_BUTTON( mSkillName[page][i] ),
@@ -3177,21 +3200,24 @@ void GuiChrSheet::drawSkill( mbr_t *org, mbr_t *mbr, long page )
 
 		// ٥
 
-		sn_printf( str, SCREEN_WIDTH, "%ld",
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%ld",
 				mbr_lev );
 		gtk_label_set_text( GTK_LABEL( mSkillLev[page][i] ),
 				str );
 
 		// и
 
-		sn_printf( str, SCREEN_WIDTH, "%ld",
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%ld",
 				mbr_exp );
 		gtk_label_set_text( GTK_LABEL( mSkillExp[page][i] ),
 				str );
 
 		// ɬ׷и
 
-		sn_printf( str, SCREEN_WIDTH, "%ld",
+		sn_printf( str, SCREEN_WIDTH * CHAR_MAX_LEN_UTF_8,
+				"%ld",
 				mbr_need_exp );
 		gtk_label_set_text( GTK_LABEL( mSkillNeedExp[page][i] ),
 				str );
@@ -3259,7 +3285,8 @@ void GuiChrSheet::drawItem( mbr_t *org, mbr_t *mbr )
 		return;
 	item_t *item = item_head->next;
 
-	for( long i = 0; i < MBR_ITEM_MAX_N; i++ ){
+	long i;
+	for( i = 0; i < MBR_ITEM_MAX_N; i++ ){
 		if( item == NULL )
 			break;
 		if( item == item_head )
@@ -3270,6 +3297,9 @@ void GuiChrSheet::drawItem( mbr_t *org, mbr_t *mbr )
 
 		item = item->next;
 	}
+	for( ; i < MBR_ITEM_MAX_N; i++ ){
+		gtk_label_set_text( GTK_LABEL( mItemName[i] ), "" );
+	}
 #endif // D_GTK
 }
 
@@ -3292,11 +3322,13 @@ void GuiChrSheet::drawEquip( mbr_t *org, mbr_t *mbr )
 		return;
 
 	for( long i = 0; i < EQUIP_KIND_MAX_N; i++ ){
-		if( item[i].kind == ITEM_KIND_NULL )
-			continue;
-
-		gtk_label_set_text( GTK_LABEL( mEquipName[i] ),
-				item[i].name );
+		if( item[i].kind == ITEM_KIND_NULL ){
+			gtk_label_set_text( GTK_LABEL( mEquipName[i] ),
+					"" );
+		} else {
+			gtk_label_set_text( GTK_LABEL( mEquipName[i] ),
+					item[i].name );
+		}
 	}
 #endif // D_GTK
 }
@@ -3364,16 +3396,18 @@ bool GuiChrSheet::nameChanged()
 	if( !chk_sel_data_n( DATA_N_NAME, get_mbr_data_edit_kind() ) )
 		return false;
 
+	const char *s;
+
 #ifdef D_GTK
-	str_nz_cpy( mbrData->name,
-			gtk_entry_get_text( GTK_ENTRY( mStatName ) ),
+	s = cut_utf_str( gtk_entry_get_text( GTK_ENTRY( mStatName ) ),
 			MBR_NAME_MAX_LEN );
+	str_nz_cpy( mbrData->name, s, MBR_NAME_MAX_BYTE );
 #endif // D_GTK
 
 #ifdef	D_MFC
-	str_nz_cpy( mbrData->name,
-			mChrSheetWin->m_Stat.m_StrNameEdit,
+	s = cut_utf_str( mChrSheetWin->m_Stat.m_StrNameEdit,
 			MBR_NAME_MAX_LEN );
+	str_nz_cpy( mbrData->name, s, MBR_NAME_MAX_BYTE );
 #endif //D_MFC
 
 	return true;
@@ -3391,15 +3425,15 @@ bool GuiChrSheet::faceChanged()
 		return false;
 
 #ifdef D_GTK
-	const gchar *s = gtk_entry_get_text( GTK_ENTRY( mStatFace ) );
-	if( s != NULL )
-		mbrData->face.mnr = s[0];
+	const gchar *sg = gtk_entry_get_text( GTK_ENTRY( mStatFace ) );
+	if( sg != NULL )
+		mbrData->face.mnr = sg[0];
 #endif // D_GTK
 
 #ifdef	D_MFC
-	const char *s = mChrSheetWin->m_Stat.m_StrFace;
-	if( s != NULL )
-		mbrData->face.mnr = s[0];
+	const char *sm = mChrSheetWin->m_Stat.m_StrFace;
+	if( sm != NULL )
+		mbrData->face.mnr = sm[0];
 #endif //D_MFC
 
 	return true;
@@ -3432,16 +3466,18 @@ bool GuiChrSheet::raceNameChanged()
 	if( !chk_sel_data_n( DATA_N_RACE_NAME, get_mbr_data_edit_kind() ) )
 		return false;
 
+	const char *s;
+
 #ifdef D_GTK
-	str_nz_cpy( mbrData->race.name,
-			gtk_entry_get_text( GTK_ENTRY( mStatRaceName ) ),
+	s = cut_utf_str( gtk_entry_get_text( GTK_ENTRY( mStatRaceName ) ),
 			RACE_NAME_MAX_LEN );
+	str_nz_cpy( mbrData->race.name, s, RACE_NAME_MAX_BYTE );
 #endif // D_GTK
 
 #ifdef	D_MFC
-	str_nz_cpy( mbrData->race.name,
-			mChrSheetWin->m_Stat.m_StrRaceName,
+	s = cut_utf_str( mChrSheetWin->m_Stat.m_StrRaceName,
 			RACE_NAME_MAX_LEN );
+	str_nz_cpy( mbrData->race.name, s, RACE_NAME_MAX_BYTE );
 #endif //D_MFC
 
 	return true;
