@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiClassEdit.cpp,v 1.8 2009/03/04 11:47:40 bowkenken Exp $
+* $Id: GuiClassEdit.cpp,v 1.9 2009/06/01 06:29:57 bowkenken Exp $
 ***************************************************************/
 
 ////////////////////////////////////////////////////////////////
@@ -494,7 +494,7 @@ void	GuiClassEdit::setClassName()
 	const gchar *name = gtk_entry_get_text(
 			GTK_ENTRY( mEntryName ) );
 
-	str_nz_cpy( classData->name, name, CLASS_NAME_MAX_LEN );
+	str_nz_cpy( classData->name, name, CLASS_NAME_MAX_BYTE );
 #endif // D_GTK
 }
 
