@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: GuiStat.cpp,v 1.26 2009/05/14 02:29:21 bowkenken Exp $
+* $Id: GuiStat.cpp,v 1.28 2009/06/01 06:29:57 bowkenken Exp $
 ***************************************************************/
 
 #define GUI_STAT_CPP
@@ -240,12 +240,12 @@ void GuiStat::newWinMbr( mbr_t *mbr, GtkWidget *vBox )
 
 	WSCstring sName, sAct, sStat, sHp, sMp;
 	long nHp, nMp, nMaxHp, nMaxMp;
-	char buf[127 + 1];
+	static char buf[80 * 8 + 1];
 
-	sprintf( buf, "%*c", MBR_NAME_MAX_LEN, ' ' );
+	sprintf( buf, "%*c", MBR_NAME_MAX_BYTE, ' ' );
 	sName = buf;
 
-	sprintf( buf, "%*c", ACT_MSG_MAX_LEN, ' ' );
+	sprintf( buf, "%*c", ACT_MSG_MAX_BYTE, ' ' );
 	sAct = buf;
 
 	sprintf( buf, "%*c", WIN_STAT_DRAW_WIDTH, ' ' );
