@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: call.cpp,v 1.101 2009/05/13 23:36:57 bowkenken Exp $
+* $Id: call.cpp,v 1.103 2009/05/31 07:23:44 bowkenken Exp $
 ***************************************************************/
 
 #define	CALL_CPP
@@ -1034,10 +1034,41 @@ void	call_pcg_dun_scroll( long map_x, long map_y )
 #endif
 }
 
+/***************************************************************
+* 롦ѥ֤
+* bool_t flagSub : ֡뤫?
+* return : 
+***************************************************************/
+
+long	call_pcg_dun_get_crsr_width( bool_t flagSub )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	return gPcgDun.getCrsrWidth( !!flagSub );
+#endif
+
+	return 0;
+}
+
+/***************************************************************
+* 롦ѥι⤵֤
+* bool_t flagSub : ֡뤫?
+* return : ⤵
+***************************************************************/
+
+long	call_pcg_dun_get_crsr_height( bool_t flagSub )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	return gPcgDun.getCrsrHeight( !!flagSub );
+#endif
+
+	return 0;
+}
+
 /***************************************************************
 * 饯κüκɸ֤
 * chr_t *chr : 饯
 * bool_t flagPre : 1 κɸ
+* return : üκɸ
 ***************************************************************/
 
 long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
@@ -1074,6 +1105,7 @@ long	call_pcg_dun_get_chr_draw_left( chr_t *chr, bool_t flagPre )
 * 饯αüκɸ֤
 * chr_t *chr : 饯
 * bool_t flagPre : 1 κɸ
+* return : üκɸ
 ***************************************************************/
 
 long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
@@ -1110,6 +1142,7 @@ long	call_pcg_dun_get_chr_draw_right( chr_t *chr, bool_t flagPre )
 * 饯ξüκɸ֤
 * chr_t *chr : 饯
 * bool_t flagPre : 1 κɸ
+* return : üκɸ
 ***************************************************************/
 
 long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
@@ -1146,6 +1179,7 @@ long	call_pcg_dun_get_chr_draw_top( chr_t *chr, bool_t flagPre )
 * 饯βüκɸ֤
 * chr_t *chr : 饯
 * bool_t flagPre : 1 κɸ
+* return : üκɸ
 ***************************************************************/
 
 long	call_pcg_dun_get_chr_draw_bottom( chr_t *chr, bool_t flagPre )
@@ -1316,6 +1350,17 @@ void	call_game_sound_play( long kind, long n )
 #endif
 }
 
+/***************************************************************
+* SE 
+***************************************************************/
+
+void	call_game_sound_stop( void )
+{
+#if	defined( D_WS ) || defined( D_GTK ) || defined( D_MFC )
+	gSound.stop();
+#endif
+}
+
 /***************************************************************
 * Υ祤ƥåֹ֤
 * return : 祤ƥåֹ
