@@ -1,6 +1,6 @@
 /***************************************************************
 * L&L - Labyrinths & Legends
-* Copyright (c) 1993-2008 YOSHIMURA Tomohiko All rights reserved.
+* Copyright (c) 1993-2009 YOSHIMURA Tomohiko All rights reserved.
 * 
 * Created by BowKenKen
 *   URL: https://sourceforge.jp/projects/lnl/
@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: fight.c,v 1.133 2008/09/20 00:28:04 bowkenken Exp $
+* $Id: fight.c,v 1.159 2009/06/01 13:47:35 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -35,17 +35,6 @@
 #define	FIGHT_C
 #include	"inc.h"
 
-/***************************************************************
-* ٥ȹ
-***************************************************************/
-
-/* ٥ˤ빶Ψγ */
-#define	MON_ADD_ATTACK_RATE_BGN_N	((rate_t)20)
-/* ٥ˤ빶Ψνλ */
-#define	MON_ADD_ATTACK_RATE_END_N	((rate_t)1)
-/* ٥ˤ빶ΨѲ */
-#define	MON_ADD_ATTACK_RATE_ADD_N	((rate_t)-1)
-
 /***************************************************************
 * ٥ɶζ
 ***************************************************************/
@@ -114,6 +103,16 @@
 
 #define	NINJA_CRTCL_RATE	((rate_t)150)
 
+/* ֡ס֡ɸפΨ */
+
+#define	KILLER_RATE	((rate_t)150)
+#define	BANE_RATE	((rate_t)150)
+#define	SLAYER_RATE	((rate_t)150)
+
+#define	BLOCK_RATE	((rate_t)75)
+#define	GUARD_RATE	((rate_t)75)
+#define	PROTECT_RATE	((rate_t)75)
+
 /* ɸ(⤷Ƥʤ)ɸϥåΨ */
 
 #define	DEF_DEF_RATE	((rate_t)150)
@@ -380,16 +379,18 @@ bool_t	fight_throw( chr_t *chr1, chr_t *chr2, attack_t *dflt_attack )
 	if( chr2 == NULL )
 		return FALSE;
 
-	eq = get_mbr_item_asgn_equip( chr1 );
-	if( eq == NULL )
-		return FALSE;
+	if( is_mbr( chr1 ) ){
+		eq = get_mbr_item_asgn_equip( chr1 );
+		if( eq == NULL )
+			return FALSE;
 
-	/* check stick */
+		/* check stick */
 
-	if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_STICK ){
-		if( !zap_stick( chr1, &(eq[EQUIP_KIND_BOW]) ) )
-			clr_chr_trgt_act( chr1, FALSE );
-		return TRUE;
+		if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_STICK ){
+			if( !zap_stick( chr1, &(eq[EQUIP_KIND_BOW]) ) )
+				clr_chr_trgt_act( chr1, FALSE );
+			return TRUE;
+		}
 	}
 
 	d = get_trgt_range( chr1 );
@@ -844,7 +845,6 @@ bool_t	fight(
 	long	i;
 
 	attack_n = calc_attack_n( o_p, attack );
-	hit_n = 0;
 
 	/* ܤɽ */
 
@@ -857,18 +857,29 @@ bool_t	fight(
 	/* begin */
 	bgn_sync_vfx_num();
 
+	hit_n = 0;
 	for( i = 0; i < attack_n; i++ ){
-		if( fight_x_1( o_p, d_p, attack, range ) )
+		if( fight_x_1( o_p, d_p, attack, range, FALSE ) ){
 			hit_n++;
+		} else {
+			if( fight_two_sword_fencing( o_p, d_p,
+					attack, range ) ){
+				hit_n++;
+			}
+		}
 	}
 
 	/* end */
 	end_sync_vfx_num();
 
-	if( hit_n >= 1 )
-		return TRUE;
-	else
+	if( hit_n < 1 )
 		return FALSE;
+
+	/* 󥿡 */
+
+	fight_counter( d_p, o_p );
+
+	return TRUE;
 }
 
 /***************************************************************
@@ -902,17 +913,32 @@ long	calc_attack_n( chr_t *o_p, const attack_t *attack )
 
 long	calc_attack_n_fig( chr_t *o_p, const attack_t *attack )
 {
+	abl_kind_t	abl;
+	long	lev;
+	rate_t	rate;
+
 	if( o_p == NULL )
-		return 0;
+		return SKILL_COMBO_MIN_N;
+	if( !is_mbr( o_p ) )
+		return SKILL_COMBO_MIN_N;
 	if( attack == NULL )
-		return 0;
-
+		return SKILL_COMBO_MIN_N;
 	if( attack->flg_throw )
-		return 0;
+		return SKILL_COMBO_MIN_N;
 	if( attack->flg_monk )
-		return 0;
+		return SKILL_COMBO_MIN_N;
 
-	return 1;
+	if( !chk_ena_skill( o_p, SKILL_KIND_DOUBLE_ATTACK ) )
+		return SKILL_COMBO_MIN_N;
+
+	abl = (abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_DOUBLE_ATTACK);
+	lev = get_lev( o_p, abl );
+	rate = SKILL_FIG_BASE_RATE;
+	rate += SKILL_FIG_ADD_RATE * lev;
+
+	print_msg( FLG_MSG_DEBUG, "FIG combo rate: %ld", rate );
+
+	return count_randm_rate( rate );
 }
 
 /***************************************************************
@@ -924,40 +950,30 @@ long	calc_attack_n_fig( chr_t *o_p, const attack_t *attack )
 
 long	calc_attack_n_mon( chr_t *o_p, const attack_t *attack )
 {
-	rate_t	rate, add_rate;
+	abl_kind_t	abl;
 	long	lev;
-	rate_t	r;
-	long	n;
+	rate_t	rate;
 
 	if( o_p == NULL )
-		return 0;
+		return SKILL_COMBO_MIN_N;
+	if( !is_mbr( o_p ) )
+		return SKILL_COMBO_MIN_N;
 	if( attack == NULL )
-		return 0;
-
+		return SKILL_COMBO_MIN_N;
 	if( !attack->flg_monk )
-		return 0;
+		return SKILL_COMBO_MIN_N;
 
-	rate = (rate_t)_100_PERCENT;
-	add_rate = MON_ADD_ATTACK_RATE_BGN_N;
-	lev = get_lev( o_p, ABL_KIND_MON );
-	for( ; lev > 0; lev-- ){
-		if( MON_ADD_ATTACK_RATE_ADD_N >= +1 )
-			if( add_rate >= MON_ADD_ATTACK_RATE_END_N )
-				break;
-		if( MON_ADD_ATTACK_RATE_ADD_N <= -1 )
-			if( add_rate <= MON_ADD_ATTACK_RATE_END_N )
-				break;
+	if( !chk_ena_skill( o_p, SKILL_KIND_COMBO ) )
+		return SKILL_COMBO_MIN_N;
 
-		rate += add_rate;
-		add_rate += MON_ADD_ATTACK_RATE_ADD_N;
-	}
-	rate += lev * MON_ADD_ATTACK_RATE_END_N;
+	abl = (abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_COMBO);
+	lev = get_lev( o_p, abl );
+	rate = SKILL_MON_BASE_RATE;
+	rate += SKILL_MON_ADD_RATE * lev;
 
-	n = 0;
-	for( r = randm( rate ) + 1; r > 0; r -= _100_PERCENT )
-		n++;
+	print_msg( FLG_MSG_DEBUG, "MON combo rate: %ld", rate );
 
-	return n;
+	return count_randm_rate( rate );
 }
 
 /***************************************************************
@@ -969,15 +985,109 @@ long	calc_attack_n_mon( chr_t *o_p, const attack_t *attack )
 
 long	calc_attack_n_hun( chr_t *o_p, const attack_t *attack )
 {
+	abl_kind_t	abl;
+	long	lev;
+	rate_t	rate;
+
 	if( o_p == NULL )
-		return 0;
+		return SKILL_COMBO_MIN_N;
+	if( !is_mbr( o_p ) )
+		return SKILL_COMBO_MIN_N;
 	if( attack == NULL )
-		return 0;
-
+		return SKILL_COMBO_MIN_N;
 	if( !attack->flg_throw )
-		return 0;
+		return SKILL_COMBO_MIN_N;
 
-	return 1;
+	if( !chk_ena_skill( o_p, SKILL_KIND_RAPID_SHOOT ) )
+		return SKILL_COMBO_MIN_N;
+
+	abl = (abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_RAPID_SHOOT);
+	lev = get_lev( o_p, abl );
+	rate = SKILL_HUN_BASE_RATE;
+	rate += SKILL_HUN_ADD_RATE * lev;
+
+	print_msg( FLG_MSG_DEBUG, "HUN combo rate: %ld", rate );
+
+	return count_randm_rate( rate );
+}
+
+/***************************************************************
+* 󥿡ȿ׻
+* chr_t *d_p : ȿ¦饯
+* return : ȿ
+***************************************************************/
+
+long	calc_counter_n( chr_t *d_p )
+{
+	abl_kind_t	abl;
+	long	lev;
+	rate_t	rate;
+
+	if( d_p == NULL )
+		return SKILL_COUNTER_MIN_N;
+	if( !is_mbr( d_p ) )
+		return SKILL_COUNTER_MIN_N;
+
+	if( !chk_ena_skill( d_p, SKILL_KIND_COUNTER ) )
+		return SKILL_COUNTER_MIN_N;
+
+	if( get_def_abl( d_p ) != ABL_KIND_MON )
+		return SKILL_COUNTER_MIN_N;
+
+	abl = (abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_COUNTER);
+	lev = get_lev( d_p, abl );
+	rate = SKILL_COUNTER_BASE_RATE;
+	rate += SKILL_COUNTER_ADD_RATE * lev;
+
+	print_msg( FLG_MSG_DEBUG, "counter rate: %ld", rate );
+
+	return count_randm_rate( rate );
+}
+
+/***************************************************************
+* ήͽ׻
+* chr_t *o_p : ¦饯
+* const attack_t *attack : ǡ
+* return : 
+***************************************************************/
+
+long	calc_two_sword_fencing_n( chr_t *o_p, const attack_t *attack )
+{
+	item_t	*eq;
+	abl_kind_t	abl;
+	long	lev;
+	rate_t	rate;
+
+	if( o_p == NULL )
+		return SKILL_TWO_SWORD_FENCING_MIN_N;
+	if( !is_mbr( o_p ) )
+		return SKILL_TWO_SWORD_FENCING_MIN_N;
+	if( attack == NULL )
+		return SKILL_TWO_SWORD_FENCING_MIN_N;
+	if( attack->flg_throw )
+		return SKILL_TWO_SWORD_FENCING_MIN_N;
+	if( attack->flg_monk )
+		return SKILL_TWO_SWORD_FENCING_MIN_N;
+
+	if( !chk_ena_skill( o_p, SKILL_KIND_TWO_SWORD_FENCING ) )
+		return SKILL_TWO_SWORD_FENCING_MIN_N;
+
+	eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
+	if( eq == NULL )
+		return SKILL_TWO_SWORD_FENCING_MIN_N;
+	if( eq[EQUIP_KIND_WIELDING].kind != ITEM_KIND_WPN )
+		return SKILL_TWO_SWORD_FENCING_MIN_N;
+	if( eq[EQUIP_KIND_SHIELD].kind != ITEM_KIND_WPN )
+		return SKILL_TWO_SWORD_FENCING_MIN_N;
+
+	abl = (abl_kind_t)(ABL_KIND_MAX_N + SKILL_KIND_TWO_SWORD_FENCING);
+	lev = get_lev( o_p, abl );
+	rate = SKILL_TWO_SWORD_FENCING_BASE_RATE;
+	rate += SKILL_TWO_SWORD_FENCING_ADD_RATE * lev;
+
+	print_msg( FLG_MSG_DEBUG, "2 sword rate: %ld", rate );
+
+	return count_randm_rate( rate );
 }
 
 /***************************************************************
@@ -986,18 +1096,22 @@ long	calc_attack_n_hun( chr_t *o_p, const attack_t *attack )
 * chr_t *d_p : ɸ¦饯
 * const attack_t *attack : ǡ
 * long range : Υ
+* bool_t flg_counter : 󥿡
 * return : ?
 ***************************************************************/
 
 bool_t	fight_x_1(
 	chr_t *o_p, chr_t *d_p,
-	const attack_t *attack, long range
+	const attack_t *attack, long range,
+	bool_t flg_counter
 )
 {
 	chr_kind_t	o_k, d_k;
-	long	o_hit, o_dam;
-	static char	o_name[CHR_NAME_MAX_LEN + 1];
-	static char	d_name[CHR_NAME_MAX_LEN + 1];
+	long	o_hit, o_dam, o_dam_real;
+	rate_t	o_crtcl;
+	static char	o_name[CHR_NAME_MAX_BYTE + 1];
+	static char	d_name[CHR_NAME_MAX_BYTE + 1];
+	rate_t	o_skill_dam;
 	long	d_def, d_ac;
 	rate_t	d_resi;
 	abl_val_t	*d_hp;
@@ -1015,6 +1129,7 @@ bool_t	fight_x_1(
 	bool_t	flg_catch_food;
 	char	mjr;
 	item_t	arw;
+	sound_kind_t	sk;
 
 	if( attack == NULL )
 		return FALSE;
@@ -1043,7 +1158,7 @@ bool_t	fight_x_1(
 
 	/* ¦̾μ */
 
-	str_nz_cpy( o_name, o_p->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( o_name, o_p->name, CHR_NAME_MAX_BYTE );
 
 	/* ξǤƮϽʤ */
 
@@ -1126,13 +1241,13 @@ bool_t	fight_x_1(
 	/* ɸ¦̾ȥǡμ */
 
 	if( flg_d_null ){
-		str_nz_cpy( d_name, MSG_NULL, CHR_NAME_MAX_LEN );
+		str_nz_cpy( d_name, MSG_NULL, CHR_NAME_MAX_BYTE );
 		d_hp = NULL;
 		d_fx = NULL;
 		d_x = 0;
 		d_y = 0;
 	} else {
-		str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_LEN );
+		str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_BYTE );
 		d_hp = &(d_p->abl.hp);
 		d_fx = &(d_p->fx);
 		d_x = d_p->x;
@@ -1200,6 +1315,16 @@ bool_t	fight_x_1(
 
 	mjr = MNSTR_THROW_MJR;
 	if( attack->flg_throw ){
+		sound_kind_t	sk;
+
+		if( o_k == CHR_KIND_MBR )
+			sk = SOUND_KIND_FIGHT_ATTACK_THROW_MEMBER;
+		else if( o_k == CHR_KIND_MNSTR )
+			sk = SOUND_KIND_FIGHT_ATTACK_THROW_MONSTER;
+		else
+			sk = SOUND_KIND_NULL;
+		call_game_sound_play( sk, 1 );
+
 		/* ꤲʪ */
 		if( (o_k == CHR_KIND_MBR) && (eq != NULL) )
 			mjr = get_item_mjr( &(eq[EQUIP_KIND_ARW]) );
@@ -1239,7 +1364,19 @@ bool_t	fight_x_1(
 	o_hit = o_hit * get_chr_throw_range_rate( o_p, d_p ) / _100_PERCENT;
 
 	o_dam = get_dam( o_p, attack );
-	flg_crtcl = rate_randm( get_crtcl( o_p, d_p, attack ) );
+
+	o_crtcl = get_crtcl( o_p, d_p, attack );
+	/* ֡׸ */
+	if( chk_killer( o_p, d_p, attack->flg_throw ) ){
+		o_crtcl = o_crtcl * KILLER_RATE / _100_PERCENT;
+		print_msg( FLG_MSG_DEBUG, "killer" );
+	}
+	/* ֡ɸ׸ */
+	if( chk_block( o_p, d_p, attack->flg_throw ) ){
+		o_crtcl = o_crtcl * BLOCK_RATE / _100_PERCENT;
+		print_msg( FLG_MSG_DEBUG, "block" );
+	}
+	flg_crtcl = rate_randm( o_crtcl );
 
 	if( !flg_d_null ){
 		o_dam = roll_dice( o_dam, TRUE );
@@ -1256,9 +1393,36 @@ bool_t	fight_x_1(
 	else
 		flg_ninja_crtcl = FALSE;
 
+	/* ֡׸ */
+
+	if( chk_bane( o_p, d_p, attack->flg_throw ) ){
+		o_hit = o_hit * BANE_RATE / _100_PERCENT;
+		print_msg( FLG_MSG_DEBUG, "bane" );
+	}
 	if( chk_slayer( o_p, d_p, attack->flg_throw ) ){
-		o_hit *= 2;
-		o_dam *= 2;
+		o_dam = o_dam * SLAYER_RATE / _100_PERCENT;
+		print_msg( FLG_MSG_DEBUG, "slayer" );
+	}
+
+	/* ֡ɸ׸ */
+
+	if( chk_guard( o_p, d_p, attack->flg_throw ) ){
+		o_hit = o_hit * GUARD_RATE / _100_PERCENT;
+		print_msg( FLG_MSG_DEBUG, "guard" );
+	}
+	if( chk_protect( o_p, d_p, attack->flg_throw ) ){
+		o_dam = o_dam * PROTECT_RATE / _100_PERCENT;
+		print_msg( FLG_MSG_DEBUG, "protect" );
+	}
+
+	/* Ρ֥᡼ϡפθ */
+
+	o_skill_dam = calc_skill_rate( o_p,
+			cv_resi_to_skill_dam( attack->resi_kind ) );
+	o_dam = o_dam * o_skill_dam / _100_PERCENT;
+	if( o_skill_dam != _100_PERCENT ){
+		print_msg( FLG_MSG_DEBUG, "skill damage: %ld%%",
+				o_skill_dam );
 	}
 
 	/* ʪ */
@@ -1274,6 +1438,21 @@ bool_t	fight_x_1(
 	/* ʤ */
 
 	if( flg_d_null || (!flg_crtcl && (d_def > o_hit)) ){
+		sound_kind_t	sk;
+
+		if( flg_d_null ){
+			sk = SOUND_KIND_NULL;
+		} else if( is_xx( d_p ) ){
+			sk = SOUND_KIND_FIGHT_DEFENSE_MISS_MONSTER_BOSS_LAST;
+		} else if( is_mnstr( d_p ) ){
+			sk = SOUND_KIND_FIGHT_DEFENSE_MISS_MONSTER;
+		} else if( is_mbr( d_p ) ){
+			sk = SOUND_KIND_FIGHT_DEFENSE_MISS_MEMBER;
+		} else {
+			sk = SOUND_KIND_NULL;
+		}
+		call_game_sound_play( sk, 1 );
+
 		if( flg_d_null ){
 			print_msg( FLG_MSG_ERR, MSG_ERR_MNSTR_NULL );
 		} else {
@@ -1290,11 +1469,11 @@ bool_t	fight_x_1(
 		}
 
 		if( o_k != CHR_KIND_MBR )
-			return TRUE;
+			return FALSE;
 		if( eq == NULL )
-			return TRUE;
+			return FALSE;
 		if( !attack->flg_throw )
-			return TRUE;
+			return FALSE;
 
 		/* ֹν */
 
@@ -1306,7 +1485,7 @@ bool_t	fight_x_1(
 			dec_throw( (mbr_t *)o_p, TRUE, d_x, d_y );
 		}
 
-		return TRUE;
+		return FALSE;
 	}
 
 	/* 񤹤 */
@@ -1358,34 +1537,69 @@ bool_t	fight_x_1(
 
 	/* ⤬ä */
 
+	if( o_dam < 0 )
+		o_dam = 0;
+	if( flg_crtcl )
+		o_dam *= 2;
+
+	/* ºݤΥ᡼˽ */
+
+	o_dam_real = o_dam;
+	if( d_hp != NULL)
+		if( o_dam_real > d_hp->n )
+			o_dam_real = d_hp->n;
+
+	/* ̲ */
+
+	sk = SOUND_KIND_NULL;
+	if( o_dam <= 0 ){
+		sk = SOUND_KIND_NULL;
+	} else if( flg_ninja_crtcl ){
+		if( is_mnstr( d_p ) )
+			sk = SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MONSTER;
+		else
+			sk = SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MEMBER;
+	} else if( flg_crtcl ){
+		if( is_mnstr( d_p ) )
+			sk = SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MONSTER;
+		else
+			sk = SOUND_KIND_FIGHT_DEFENSE_CRITICAL_MEMBER;
+	} else {
+		if( is_mnstr( d_p ) )
+			sk = SOUND_KIND_FIGHT_DEFENSE_HIT_MONSTER;
+		else
+			sk = SOUND_KIND_FIGHT_DEFENSE_HIT_MEMBER;
+	}
+	call_game_sound_play( sk, 1 );
+
 	/* ᡼ɽ */
 
 	if( o_dam <= 0 ){
-		o_dam = 0;
+		;
 	} else if( flg_ninja_crtcl ){
 		curs_attrset_chr( d_p, -1, TRUE );
 		print_msg( FLG_NULL, MSG_FIGHT_CRTCL_NINJA, o_name );
 		curs_attrset_dflt();
 
-		vfx_ninja_crtcl( d_k, end.x, end.y );
+		vfx_ninja_crtcl( d_p, end.x, end.y );
 	} else if( flg_crtcl ){
-		o_dam *= 2;
-
 		curs_attrset_chr( d_p, -1, TRUE );
 		print_msg( FLG_NULL, MSG_FIGHT_CRTCL_STD, o_name );
 		curs_attrset_dflt();
 
-		vfx_crtcl( d_k, end.x, end.y );
+		vfx_crtcl( d_p, end.x, end.y );
 
 		curs_attrset_chr( d_p, -1, FALSE );
-		print_msg( FLG_NULL, MSG_FIGHT_HIT_STD, d_name, o_dam );
+		print_msg( FLG_NULL, MSG_FIGHT_HIT_STD,
+				d_name, o_dam_real );
 		curs_attrset_dflt();
 	} else {
 		curs_attrset_chr( d_p, -1, FALSE );
-		print_msg( FLG_NULL, MSG_FIGHT_HIT_STD, d_name, o_dam );
+		print_msg( FLG_NULL, MSG_FIGHT_HIT_STD,
+				d_name, o_dam_real );
 		curs_attrset_dflt();
 
-		vfx_hit( d_k, end.x, end.y );
+		vfx_hit( d_p, end.x, end.y );
 	}
 
 	/* Υե */
@@ -1429,6 +1643,14 @@ bool_t	fight_x_1(
 	/* ɲø */
 
 	added_fx( d_p, attack->resi_kind );
+	added_fx_wpn_randm_art( o_p, d_p, attack->flg_throw );
+
+	fx_wpn_randm_art_drain( WPN_RANDM_ART_MNR_DRAIN_HP,
+			o_p, d_p, o_dam_real, attack->flg_throw );
+	fx_wpn_randm_art_drain( WPN_RANDM_ART_MNR_DRAIN_MP,
+			o_p, d_p, o_dam_real, attack->flg_throw );
+	fx_wpn_randm_art_drain( WPN_RANDM_ART_MNR_DRAIN_EXP,
+			o_p, d_p, o_dam_real, attack->flg_throw );
 
 	/* HP򸺤餹 */
 
@@ -1441,8 +1663,7 @@ bool_t	fight_x_1(
 	if( flg_dead ){
 		/*  */
 		curs_attrset_chr( d_p, -1, TRUE );
-		print_msg( FLG_NULL, MSG_FIGHT_KILL_STD,
-				o_name, d_name );
+		print_msg( FLG_NULL, MSG_FIGHT_KILL_STD, o_name, d_name );
 		curs_attrset_dflt();
 	}
 
@@ -1454,6 +1675,99 @@ bool_t	fight_x_1(
 	return TRUE;
 }
 
+/***************************************************************
+* ήˤͽ
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* const attack_t *attack : ǡ
+* long range : Υ
+* return : ?
+***************************************************************/
+
+bool_t	fight_two_sword_fencing(
+	chr_t *o_p, chr_t *d_p,
+	const attack_t *attack, long range
+)
+{
+	long	attack_n;
+	long	j;
+
+	if( o_p == NULL )
+		return FALSE;
+	if( d_p == NULL )
+		return FALSE;
+	if( attack == NULL )
+		return FALSE;
+
+	attack_n = calc_two_sword_fencing_n( o_p, attack );
+	if( attack_n <= 0 )
+		return FALSE;
+
+	curs_attrset_chr( d_p, -1, FALSE );
+	print_msg( FLG_NULL, MSG_FIGHT_TWO_SWORD_FENCING,
+			o_p->name, attack_n );
+	curs_attrset_dflt();
+
+	for( j = 0; j < attack_n; j++ )
+		if( fight_x_1( o_p, d_p, attack, range, FALSE ) )
+			return TRUE;
+
+	return FALSE;
+}
+
+/***************************************************************
+* 󥿡ˤȿ
+* chr_t *o_p : ¦饯 (ȿ¦)
+* chr_t *d_p : ɸ¦饯
+* return : ?
+***************************************************************/
+
+bool_t	fight_counter( chr_t *o_p, chr_t *d_p )
+{
+	long	attack_n;
+	attack_t	attack;
+	long	d;
+	long	hit_n;
+	long	i;
+
+	if( o_p == NULL )
+		return FALSE;
+	if( d_p == NULL )
+		return FALSE;
+
+	attack_n = calc_counter_n( o_p );
+	if( attack_n <= 0 )
+		return FALSE;
+
+	/* ˹⤷褿¦ (ɸ¦) εΥǷ׻ */
+	d = get_trgt_range( d_p );
+
+	if( !set_attack_chr_bash( o_p, &attack, 1, FALSE ) )
+		return FALSE;
+
+	/* 󥿡ɽ */
+
+	curs_attrset_chr( d_p, -1, FALSE );
+	print_msg( FLG_NULL, MSG_FIGHT_COUNTER, o_p->name, attack_n );
+	curs_attrset_dflt();
+
+	/* begin */
+	bgn_sync_vfx_num();
+
+	hit_n = 0;
+	for( i = 0; i < attack_n; i++ )
+		if( fight_x_1( o_p, d_p, &attack, d, TRUE ) )
+			hit_n++;
+
+	/* end */
+	end_sync_vfx_num();
+
+	if( hit_n >= 1 )
+		return TRUE;
+	else
+		return FALSE;
+}
+
 /***************************************************************
 * ʸ
 * chr_t *o_p : ¦饯
@@ -1473,8 +1787,9 @@ bool_t	spell_attack(
 {
 	flg_stat_t	o_stat;
 	pos_t	o_pos, d_pos;
-	static char	o_name[CHR_NAME_MAX_LEN + 1];
-	static char	d_name[CHR_NAME_MAX_LEN + 1];
+	static char	o_name[CHR_NAME_MAX_BYTE + 1];
+	static char	d_name[CHR_NAME_MAX_BYTE + 1];
+	rate_t	o_skill_dam;
 	long	dam;
 	long	ac;
 	bool_t	flg_serious;
@@ -1516,13 +1831,13 @@ bool_t	spell_attack(
 	o_stat = o_p->stat;
 	o_pos.x = o_p->x;
 	o_pos.y = o_p->y;
-	str_nz_cpy( o_name, o_p->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( o_name, o_p->name, CHR_NAME_MAX_BYTE );
 
 	/* ɸ¦ǡ */
 
 	d_pos.x = d_p->x;
 	d_pos.y = d_p->y;
-	str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_LEN );
+	str_nz_cpy( d_name, d_p->name, CHR_NAME_MAX_BYTE );
 
 	/* Ǥ뤫 */
 
@@ -1565,6 +1880,15 @@ bool_t	spell_attack(
 	dam = dam * rate / _100_PERCENT;
 	dam = roll_dice( dam, TRUE );
 
+	/* Ρ֥᡼ϡפθ */
+
+	o_skill_dam = calc_skill_rate( o_p, cv_resi_to_skill_dam( resi ) );
+	dam = dam * o_skill_dam / _100_PERCENT;
+	if( o_skill_dam != _100_PERCENT ){
+		print_msg( FLG_MSG_DEBUG, "skill damage: %ld%%",
+				o_skill_dam );
+	}
+
 	dam = calc_resi( get_resi_def( d_p, resi ), dam );
 	dam -= ac;
 	if( dam < 1 )
@@ -1636,6 +1960,119 @@ void	added_fx( chr_t *chr, resi_kind_t resi )
 	}
 }
 
+/***************************************************************
+* 饯ΥࡦƥեȤɲø
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* bool_t flg_throw : ƻ?
+***************************************************************/
+
+void	added_fx_wpn_randm_art(
+	chr_t *o_p, chr_t *d_p,
+	bool_t flg_throw
+)
+{
+	item_t	*eq;
+
+	if( o_p == NULL )
+		return;
+	if( d_p == NULL )
+		return;
+	if( !is_mbr( o_p ) )
+		return;
+
+	eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
+	if( eq == NULL )
+		return;
+
+	if( flg_throw ){
+		if( eq[EQUIP_KIND_ARW].kind == ITEM_KIND_WPN ){
+			added_fx_wpn_randm_art_item( o_p, d_p,
+					&(eq[EQUIP_KIND_ARW]) );
+		}
+		if( eq[EQUIP_KIND_BOW].kind == ITEM_KIND_WPN ){
+			added_fx_wpn_randm_art_item( o_p, d_p,
+					&(eq[EQUIP_KIND_BOW]) );
+		}
+	} else {
+		if( eq[EQUIP_KIND_WIELDING].kind == ITEM_KIND_WPN ){
+			added_fx_wpn_randm_art_item( o_p, d_p,
+					&(eq[EQUIP_KIND_WIELDING]) );
+		}
+	}
+}
+
+/***************************************************************
+* ΥࡦƥեȤɲø
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* item_t *item : ¦
+***************************************************************/
+
+void	added_fx_wpn_randm_art_item(
+	chr_t *o_p, chr_t *d_p,
+	item_t *item
+)
+{
+	wpn_randm_art_t	*art;
+	abl_kind_t	abl;
+	fx_kind_t	fx;
+	resi_kind_t	resi;
+	flg_stat_t	stat;
+	long	i;
+
+	if( item == NULL )
+		return;
+	if( item->kind != ITEM_KIND_WPN )
+		return;
+	if( d_p == NULL )
+		return;
+
+	abl = get_specialist_abl( o_p );
+
+	art = item->dat.wpn.randm_art;
+
+	for( i = 0; i < WPN_RANDM_ART_LS_MAX_N; i++ ){
+		if( art[i].kind == WPN_RANDM_ART_KIND_NULL )
+			break;
+		if( art[i].kind != WPN_RANDM_ART_KIND_ADD_STAT )
+			continue;
+
+		fx = get_wpn_randm_art_add_stat_fx( art[i].mnr );
+		if( fx == FX_KIND_NULL )
+			continue;
+
+		/* ɲø̤뤫å */
+
+		stat = cv_fx_kind_to_flg_stat( fx );
+		if( (stat != FLG_STAT_NULL) && chk_resi_stat( d_p, stat ) )
+			continue;
+
+		/* ɲø̤񹳤뤫å */
+
+		resi = cv_fx_kind_to_resi_kind( fx );
+		if( resi >= RESI_KIND_MAX_N )
+			continue;
+
+		if( resi_roll( o_p, abl, d_p, resi ) )
+			continue;
+
+		/* ɲø̤Ϥ뤫å */
+
+		if( chk_flg( d_p->stat, FLG_STAT_IRON_BODY ) ){
+			if( (o_p != NULL) && (d_p != NULL) ){
+				curs_attrset_chr( d_p, +1, FALSE );
+				print_msg( FLG_NULL, MSG_REPEL_ATTACK,
+						d_p->name, o_p->name );
+				curs_attrset_dflt();
+			}
+			continue;
+		}
+
+		fx_std( d_p, fx );
+	}
+}
+
 /***************************************************************
 * Υե
 * chr_t *o_p : ¦饯
@@ -1749,6 +2186,7 @@ bool_t	chr_break_item( chr_t *chr, item_t *item )
 {
 	long	hit;
 	attack_t	attack;
+	char	name[ITEM_NAME_MAX_BYTE + 1];
 
 	if( chr == NULL )
 		return FALSE;
@@ -1762,7 +2200,6 @@ bool_t	chr_break_item( chr_t *chr, item_t *item )
 		return TRUE;
 	}
 
-
 	if( set_attack_chr_bash( chr, &attack, 1, FALSE ) )
 		hit = get_hit( chr, &attack );
 	else
@@ -1771,16 +2208,19 @@ bool_t	chr_break_item( chr_t *chr, item_t *item )
 	hit += hit * chr->fx_data.bless;
 
 	if( ITEM_DEF > hit ){
-		print_msg( FLG_MSG_ERR, MSG_ERR_ITEM_BREAK_LEV, item->name );
+		print_msg( FLG_MSG_ERR, MSG_ERR_ITEM_BREAK_LEV,
+				item->name );
 
 		return FALSE;
 	}
 
-
-	print_msg( FLG_NULL, MSG_ITEM_BREAK, chr->name, item->name );
+	str_nz_cpy( name, item->name, ITEM_NAME_MAX_BYTE );
 
 	break_item_contents( item, chr );
-	break_item( item, TRUE );
+	if( break_item( item, TRUE ) )
+		print_msg( FLG_NULL, MSG_ITEM_BREAK, chr->name, name );
+	else
+		print_msg( FLG_MSG_ERR, MSG_ERR_ITEM_BREAK, name );
 
 	draw_item( item );
 
@@ -1788,7 +2228,53 @@ bool_t	chr_break_item( chr_t *chr, item_t *item )
 }
 
 /***************************************************************
-* м²̡֡פĴ٤
+* Υ١̤Ĵ٤
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* bool_t flg_throw : ƻ?
+* return : ?
+***************************************************************/
+
+bool_t	chk_bane( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
+{
+	if( o_p == NULL )
+		return FALSE;
+	if( d_p == NULL )
+		return FALSE;
+
+	if( chk_wpn_randm_art( WPN_RANDM_ART_KIND_BANE, d_p->face.mjr,
+			o_p, d_p, flg_throw ) ){
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+/***************************************************************
+* Υ顼̤Ĵ٤
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* bool_t flg_throw : ƻ?
+* return : ?
+***************************************************************/
+
+bool_t	chk_killer( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
+{
+	if( o_p == NULL )
+		return FALSE;
+	if( d_p == NULL )
+		return FALSE;
+
+	if( chk_wpn_randm_art( WPN_RANDM_ART_KIND_KILLER, d_p->face.mjr,
+			o_p, d_p, flg_throw ) ){
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+/***************************************************************
+* Υ쥤䡼̤Ĵ٤
 * chr_t *o_p : ¦饯
 * chr_t *d_p : ɸ¦饯
 * bool_t flg_throw : ƻ?
@@ -1797,36 +2283,83 @@ bool_t	chr_break_item( chr_t *chr, item_t *item )
 
 bool_t	chk_slayer( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
 {
-	item_t	*eq;
-
 	if( o_p == NULL )
 		return FALSE;
 	if( d_p == NULL )
 		return FALSE;
 
-	if( !is_mbr( o_p ) )
+	if( chk_wpn_randm_art( WPN_RANDM_ART_KIND_SLAYER, d_p->face.mjr,
+			o_p, d_p, flg_throw ) ){
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+/***************************************************************
+* ɶΡ֡ɡ׸̤Ĵ٤
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* bool_t flg_throw : ƻ?
+* return : ?
+***************************************************************/
+
+bool_t	chk_guard( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
+{
+	if( o_p == NULL )
+		return FALSE;
+	if( d_p == NULL )
 		return FALSE;
 
-	eq = get_mbr_item_asgn_equip( (mbr_t *)o_p );
-	if( eq == NULL )
+	if( chk_armor_randm_art( ARMOR_RANDM_ART_KIND_GUARD,
+			o_p->face.mjr, o_p, d_p ) ){
+		return TRUE;
+	}
+
+	return FALSE;
+}
+
+/***************************************************************
+* ɶΡ֥֡å׸̤Ĵ٤
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* bool_t flg_throw : ƻ?
+* return : ?
+***************************************************************/
+
+bool_t	chk_block( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
+{
+	if( o_p == NULL )
+		return FALSE;
+	if( d_p == NULL )
 		return FALSE;
 
-	if( flg_throw ){
-		if( eq[EQUIP_KIND_ARW].kind != ITEM_KIND_WPN )
-			return FALSE;
-		if( eq[EQUIP_KIND_ARW].dat.wpn.slayer == d_p->face.mjr )
-			return TRUE;
+	if( chk_armor_randm_art( ARMOR_RANDM_ART_KIND_BLOCK,
+			o_p->face.mjr, o_p, d_p ) ){
+		return TRUE;
+	}
 
-		if( eq[EQUIP_KIND_BOW].kind != ITEM_KIND_WPN )
-			return FALSE;
-		if( eq[EQUIP_KIND_BOW].dat.wpn.slayer == d_p->face.mjr )
-			return TRUE;
-	} else {
-		if( eq[EQUIP_KIND_WIELDING].kind != ITEM_KIND_WPN )
-			return FALSE;
-		if( eq[EQUIP_KIND_WIELDING].dat.wpn.slayer
-				== d_p->face.mjr )
-			return TRUE;
+	return FALSE;
+}
+
+/***************************************************************
+* ɶΡ֡ץƥȡ׸̤Ĵ٤
+* chr_t *o_p : ¦饯
+* chr_t *d_p : ɸ¦饯
+* bool_t flg_throw : ƻ?
+* return : ?
+***************************************************************/
+
+bool_t	chk_protect( chr_t *o_p, chr_t *d_p, bool_t flg_throw )
+{
+	if( o_p == NULL )
+		return FALSE;
+	if( d_p == NULL )
+		return FALSE;
+
+	if( chk_armor_randm_art( ARMOR_RANDM_ART_KIND_PROTECT,
+			o_p->face.mjr, o_p, d_p ) ){
+		return TRUE;
 	}
 
 	return FALSE;
@@ -1962,6 +2495,22 @@ long	get_hit( chr_t *p, const attack_t *attack )
 
 	hit = hit * HIT_ADJ_RATE / _100_PERCENT;
 
+	/* ǽ */
+
+	hit *= calc_skill_rate( p, SKILL_KIND_ATTACKER );
+	hit /= _100_PERCENT;
+
+	hit *= calc_skill_sub_rate( p, SKILL_KIND_BERSERKER,
+			SKILL_KIND_ATTACKER );
+	hit /= _100_PERCENT;
+
+	hit *= calc_skill_sub_rate( p, SKILL_KIND_DEFENDER,
+			SKILL_KIND_ATTACKER );
+	hit /= _100_PERCENT;
+
+	hit *= calc_skill_rate( p, SKILL_KIND_SIEGE );
+	hit /= _100_PERCENT;
+
 	if( hit < 1 )
 		hit = 1;
 
@@ -2031,6 +2580,22 @@ long	get_dam( chr_t *p, const attack_t *attack )
 
 #endif	/* FLG_ITEM_ADD_RATE */
 
+	/* ǽ */
+
+	dam *= calc_skill_rate( p, SKILL_KIND_BERSERKER );
+	dam /= _100_PERCENT;
+
+	dam *= calc_skill_sub_rate( p, SKILL_KIND_ATTACKER,
+			SKILL_KIND_BERSERKER );
+	dam /= _100_PERCENT;
+
+	dam *= calc_skill_sub_rate( p, SKILL_KIND_DEFENDER,
+			SKILL_KIND_BERSERKER );
+	dam /= _100_PERCENT;
+
+	dam *= calc_skill_rate( p, SKILL_KIND_SIEGE );
+	dam /= _100_PERCENT;
+
 	if( dam < 1 )
 		dam = 1;
 
@@ -2083,6 +2648,22 @@ long	get_def( chr_t *p )
 
 #endif	/* FLG_ITEM_ADD_RATE */
 
+	/* ǽ */
+
+	def *= calc_skill_rate( p, SKILL_KIND_DEFENDER );
+	def /= _100_PERCENT;
+
+	def *= calc_skill_sub_rate( p, SKILL_KIND_ATTACKER,
+			SKILL_KIND_DEFENDER );
+	def /= _100_PERCENT;
+
+	def *= calc_skill_sub_rate( p, SKILL_KIND_BERSERKER,
+			SKILL_KIND_DEFENDER );
+	def /= _100_PERCENT;
+
+	def *= calc_skill_rate( p, SKILL_KIND_PHALANX );
+	def /= _100_PERCENT;
+
 	if( def < 1 )
 		def = 1;
 
@@ -2245,6 +2826,14 @@ long	get_ac( chr_t *p )
 
 #endif	/* FLG_ITEM_ADD_RATE */
 
+	/* ǽ */
+
+	ac *= calc_skill_rate( p, SKILL_KIND_SENTINEL );
+	ac /= _100_PERCENT;
+
+	ac *= calc_skill_rate( p, SKILL_KIND_PHALANX );
+	ac /= _100_PERCENT;
+
 	if( ac < 1 )
 		ac = 1;
 
@@ -2318,6 +2907,11 @@ rate_t	get_wpn_crtcl( chr_t *p, const attack_t *attack )
 
 #endif	/* FLG_ITEM_ADD_RATE */
 
+	/* ǽ */
+
+	crtcl *= calc_skill_rate( p, SKILL_KIND_ASSASSIN );
+	crtcl /= _100_PERCENT;
+
 	if( crtcl < 1 )
 		crtcl = 1;
 
@@ -2384,6 +2978,10 @@ rate_t	get_armor_crtcl( chr_t *p )
 
 #endif	/* FLG_ITEM_ADD_RATE */
 
+	/* ǽ */
+
+	crtcl *= calc_skill_rate( p, SKILL_KIND_AEGIS );
+	crtcl /= _100_PERCENT;
 
 	if( crtcl < 1 )
 		crtcl = 1;
@@ -2649,6 +3247,9 @@ rate_t	get_chr_throw_range_rate( chr_t *o_p, chr_t *d_p )
 	if( d_p == NULL )
 		return( (rate_t)0 );
 
+	if( chk_xx_range() )
+		return _100_PERCENT;
+
 	rate = get_throw_range_rate(
 			o_p->trgt.true_x, o_p->trgt.true_y,
 			d_p->trgt.true_x, d_p->trgt.true_y );
@@ -2745,6 +3346,12 @@ char	*get_msg_attack( const attack_t *attack )
 		return MSG_ATTACK_CARESS_HIP;
 	case ATTACK_KIND_CARESS_CROTCH:
 		return MSG_ATTACK_CARESS_CROTCH;
+	case ATTACK_KIND_CYBERN_PUNCH:
+		return MSG_ATTACK_CYBERN_PUNCH;
+	case ATTACK_KIND_CYBERN_KICK:
+		return MSG_ATTACK_CYBERN_KICK;
+	case ATTACK_KIND_XX_SLAP:
+		return MSG_ATTACK_XX_SLAP;
 	case ATTACK_KIND_MAX_N:
 		break;
 	}
