@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: gmain.c,v 1.125 2009/03/10 12:46:14 bowkenken Exp $
+* $Id: gmain.c,v 1.129 2009/05/28 07:29:09 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -73,7 +73,7 @@ static struct termio	pre_tbuf;
 ***************************************************************/
 
 #define	OPT_ARG_MAX_LEN	128
-#define	STR_OPT	"GCUN:T:D:S:l:k:e:s:p:md:Vvh"
+#define	STR_OPT	"GCUN:P:T:D:S:l:k:e:s:p:md:Vvh"
 
 #ifdef	HAVE_GETOPT_LONG
 static struct option	long_opt[] = {
@@ -81,6 +81,7 @@ static struct option	long_opt[] = {
 	{ "cui",           no_argument,       NULL, 'C' },
 	{ "gui-and-cui",   no_argument,       NULL, 'U' },
 	{ "gnome",         required_argument, NULL, 'N' },
+	{ "set-win-pos",   required_argument, NULL, 'P' },
 	{ "text-mode",     required_argument, NULL, 'T' },
 	{ "sel-graph-dir", required_argument, NULL, 'D' },
 	{ "map-scale",     required_argument, NULL, 'S' },
@@ -109,6 +110,8 @@ char	str_usage[] = {
 	"  -U, --gui-and-cui        set GUI and CUI mode\n"
 	"  -N, --gnome              window manager is GNOME\n"
 	"                             ON or OFF\n"
+	"  -P, --set-win-pos        set window position\n"
+	"                             ON or OFF\n"
 #if	defined( DEBUG ) || !defined( NDEBUG )
 	"  -T, --text-mode=POINT    set TEXT mode:\n"
 	"                             point of font, ON or OFF\n"
@@ -289,7 +292,8 @@ void	game_main( void )
 
 		menu_load_start();
 
-		party_exit_bar();
+		if( g_load_slot_n != SAVE_N_AUTO )
+			party_exit_bar();
 	}
 
 	while( 1 ){
@@ -356,7 +360,11 @@ void	init_arg( void )
 	g_flg_cui = TRUE;
 	g_flg_gui = FALSE;
 
+	g_flg_win_pos_arg_overwrite = FALSE;
+	g_flg_gnome_arg = TRUE;
+	g_flg_set_win_pos_arg = TRUE;
 	g_flg_gnome = TRUE;
+	g_flg_set_win_pos = TRUE;
 
 	g_flg_text_mode = FALSE;
 	g_text_mode_point = 0;
@@ -438,7 +446,12 @@ void	chk_arg( int argc, char **argv )
 			g_flg_gui = TRUE;
 			break;
 		case 'N':
-			chk_opt_flg( optarg, &g_flg_gnome, TRUE );
+			g_flg_win_pos_arg_overwrite = TRUE;
+			chk_opt_flg( optarg, &g_flg_gnome_arg, TRUE );
+			break;
+		case 'P':
+			g_flg_win_pos_arg_overwrite = TRUE;
+			chk_opt_flg( optarg, &g_flg_set_win_pos_arg, TRUE );
 			break;
 		case 'T':
 			if( chk_opt_flg( optarg, &g_flg_text_mode,
@@ -622,6 +635,11 @@ void	overwrite_arg()
 		g_flg_clr_key_buf = g_flg_clr_key_buf_arg;
 		g_flg_clr_key_buf_menu = g_flg_clr_key_buf_arg;
 	}
+
+	if( g_flg_win_pos_arg_overwrite ){
+		g_flg_gnome = g_flg_gnome_arg;
+		g_flg_set_win_pos = g_flg_set_win_pos_arg;
+	}
 }
 
 /***************************************************************
