@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: imenu-tab.h,v 1.12 2009/02/22 14:52:50 bowkenken Exp $
+* $Id: imenu-tab.h,v 1.13 2009/05/26 09:39:17 bowkenken Exp $
 ***************************************************************/
 
 #ifndef	IMENU_TAB_H
@@ -230,6 +230,15 @@ menu_t	ls_menu_move_crsr[] = {
 		FLG_NULL,
 	},
 /* cursor quick move end */
+	{
+		"/cursor/individual square",
+		"<Branch>",
+		'V',
+		"t",
+		N_MSG_MENU_CRSR_IND_SQUARE, "",
+		cb_menu_crsr_ind_square, NULL,
+		FLG_NULL,
+	},
 /* cursor scroll begin */
 	{
 		"/cursor/scroll",
