@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: last-boss.c,v 1.69 2009/03/10 17:01:19 bowkenken Exp $
+* $Id: last-boss.c,v 1.72 2009/05/31 08:35:54 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -612,7 +612,6 @@ bool_t	chk_last_boss_demo( void )
 	case LAST_SCENE_N_ENTER:
 		return FALSE;
 	case LAST_SCENE_N_ENCOUNTER:
-//@@@
 		return FALSE;
 	case LAST_SCENE_N_ENCOUNTER_CUT_IN:
 	case LAST_SCENE_N_ENCOUNTER_WORDS:
@@ -620,7 +619,6 @@ bool_t	chk_last_boss_demo( void )
 	case LAST_SCENE_N_ENCOUNTER_CUT_END:
 		return TRUE;
 	case LAST_SCENE_N_EXEL:
-//@@@
 		return FALSE;
 	case LAST_SCENE_N_EXEL_ENTER:
 	case LAST_SCENE_N_EXEL_CUT_IN:
@@ -634,7 +632,6 @@ bool_t	chk_last_boss_demo( void )
 	case LAST_SCENE_N_EXEL_DIE:
 		return TRUE;
 	case LAST_SCENE_N_EXELER:
-//@@@
 		return FALSE;
 	case LAST_SCENE_N_EXELER_CUT_IN:
 	case LAST_SCENE_N_EXELER_WORDS:
@@ -648,7 +645,6 @@ bool_t	chk_last_boss_demo( void )
 	case LAST_SCENE_N_EXELER_DIE:
 		return TRUE;
 	case LAST_SCENE_N_XEX:
-//@@@
 		return FALSE;
 	case LAST_SCENE_N_XEX_CUT_IN:
 	case LAST_SCENE_N_XEX_WORDS:
@@ -1257,6 +1253,8 @@ void	open_last_boss_gate( void )
 	dun_t	*dun;
 	long	i;
 
+	call_game_sound_play( SOUND_KIND_EVENT_GATE, 1 );
+
 	dun = get_dun();
 	for( i = 0; i < dun->door_n; i++ ){
 		dun->door[i].flg &= ~(FLG_DOOR_JAMMED | FLG_DOOR_BROKEN);
@@ -1338,6 +1336,8 @@ void	draw_xx_enter( void )
 	bgn_time = time( NULL );
 	flg_end = FALSE;
 
+	call_game_sound_play( SOUND_KIND_EVENT_EARTHQUAKE, 10 );
+
 	for( i = 0; i < LOOP_MAX_1000; i++ ){
 		/*  */
 
@@ -1475,6 +1475,8 @@ void	draw_xx_enter( void )
 		}
 	}
 
+	call_game_sound_stop();
+
 	/* ̤ΰ֤򸵤᤹ */
 
 	draw->x = pre_draw.x;
@@ -2164,8 +2166,7 @@ void	set_slap_xx_arm_left( bool_t flg_slap_arm )
 	flg_slap_xx_arm_left = flg_slap_arm;
 
 	set_last_boss_ptn();
-	if( g_flg_cui )
-		redraw_map_force();
+	redraw_map_force();
 }
 
 /***************************************************************
@@ -2178,8 +2179,7 @@ void	set_slap_xx_arm_right( bool_t flg_slap_arm )
 	flg_slap_xx_arm_right = flg_slap_arm;
 
 	set_last_boss_ptn();
-	if( g_flg_cui )
-		redraw_map_force();
+	redraw_map_force();
 }
 
 /***************************************************************
@@ -2563,6 +2563,40 @@ void	act_mnstr_xx( mnstr_t *p )
 	redraw_map();
 }
 
+/***************************************************************
+* XX Υθ̲
+* xx_act_kind_t kind : μ
+***************************************************************/
+
+void	play_sound_xx( xx_act_kind_t kind )
+{
+	sound_kind_t	sk;
+
+	sk = SOUND_KIND_NULL;
+
+	switch( kind ){
+	case XX_ACT_KIND_NULL:
+	case XX_ACT_KIND_MAX_N:
+		break;
+	case XX_ACT_KIND_HEAT:
+	case XX_ACT_KIND_COLD:
+	case XX_ACT_KIND_MIND:
+	case XX_ACT_KIND_ACID:
+		sk = SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_ATTACK;
+		break;
+	case XX_ACT_KIND_PARALYZE:
+	case XX_ACT_KIND_POISON:
+	case XX_ACT_KIND_SLEEP:
+		sk = SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_WEAKEN;
+		break;
+	case XX_ACT_KIND_SLAP:
+		sk = SOUND_KIND_FIGHT_ATTACK_LAST_BOSS_SLAP;
+		break;
+	}
+
+	call_game_sound_play( sk, 1 );
+}
+
 /***************************************************************
 * XX μʸ
 * mnstr_t *p : XX Υ饯ǡ
@@ -2614,7 +2648,9 @@ void	xx_act_heat( mnstr_t *p )
 {
 	set_open_xx_jaw( TRUE );
 
+	play_sound_xx( XX_ACT_KIND_HEAT );
 	xx_act_heat_draw( p );
+	play_sound_xx( XX_ACT_KIND_HEAT );
 	xx_act_heat_draw( p );
 
 	redraw_map();
@@ -2701,6 +2737,7 @@ void	xx_act_heat_draw( mnstr_t *p )
 
 void	xx_act_cold( mnstr_t *p )
 {
+	play_sound_xx( XX_ACT_KIND_COLD );
 	xx_act_cold_draw( p );
 
 	redraw_map();
@@ -2870,6 +2907,7 @@ pos_t	*get_xx_laser_dxy( void )
 
 void	xx_act_mind( mnstr_t *p )
 {
+	play_sound_xx( XX_ACT_KIND_MIND );
 	xx_act_mind_draw( p );
 
 	redraw_map();
@@ -3048,7 +3086,9 @@ void	xx_act_acid( mnstr_t *p )
 {
 	set_open_xx_jaw( TRUE );
 
+	play_sound_xx( XX_ACT_KIND_ACID );
 	xx_act_acid_draw( p );
+	play_sound_xx( XX_ACT_KIND_ACID );
 	xx_act_acid_draw( p );
 
 	redraw_map();
@@ -3312,6 +3352,7 @@ void	xx_act_rotation( mnstr_t *p )
 {
 	set_open_xx_jaw( TRUE );
 
+	play_sound_xx( XX_ACT_KIND_PARALYZE );
 	xx_act_rotation_draw( p );
 
 	redraw_map();
@@ -3475,6 +3516,7 @@ void	xx_act_whirl( mnstr_t *p )
 {
 	set_open_xx_jaw( TRUE );
 
+	play_sound_xx( XX_ACT_KIND_POISON );
 	xx_act_whirl_draw( p );
 
 	redraw_map();
@@ -3605,6 +3647,7 @@ void	xx_act_whirl_draw( mnstr_t *p )
 
 void	xx_act_fan( mnstr_t *p )
 {
+	play_sound_xx( XX_ACT_KIND_SLEEP );
 	xx_act_fan_draw( p );
 
 	redraw_map();
@@ -3757,7 +3800,9 @@ void	xx_act_fan_draw( mnstr_t *p )
 
 void	xx_act_slap( mnstr_t *p )
 {
+	play_sound_xx( XX_ACT_KIND_SLAP );
 	xx_act_slap_draw( p );
+	play_sound_xx( XX_ACT_KIND_SLAP );
 	xx_act_slap_draw( p );
 
 	redraw_map();
