@@ -25,7 +25,7 @@
 *   59 Temple Place, Suite 330, Boston, MA 02111-1307, USA
 * ؼ񤤤Ƥ
 * 
-* $Id: mnstr.c,v 1.219 2009/05/23 15:59:37 bowkenken Exp $
+* $Id: mnstr.c,v 1.224 2009/06/01 05:05:04 bowkenken Exp $
 ***************************************************************/
 
 /***************************************************************
@@ -332,7 +332,7 @@ void	new_mnstr( mnstr_t *mnstr )
 	mnstr->act.dflt_kind_mnstr
 			= ACT_KIND_MNSTR_FIGHT;
 	str_nz_cpy( mnstr->act.dflt_msg_mnstr,
-			MSG_MENU_MARK_FIGHT, ACT_MSG_MAX_LEN );
+			MSG_MENU_MARK_FIGHT, ACT_MSG_MAX_BYTE );
 	clr_chr_trgt_act( mnstr, TRUE );
 	mnstr->pre_act = mnstr->act;
 
@@ -566,7 +566,7 @@ mnstr_t	*make_mnstr_alloc(
 
 	new_mnstr( p );
 
-	str_nz_cpy( p->name, tab->name, MNSTR_NAME_MAX_LEN );
+	str_nz_cpy( p->name, tab->name, MNSTR_NAME_MAX_BYTE );
 	p->x = MAP_DEL_X;
 	p->y = MAP_DEL_Y;
 	p->pre_x = p->x;
@@ -1451,10 +1451,8 @@ bool_t	set_flg_find_mnstr( mnstr_t *p )
 	p->flg_map &= ~FLG_MAP_CHR_FIND;
 	flg = FLG_NULL;
 	for( i = 0; i < MBR_MAX_N; i++ ){
-
 		/* ȯ? */
 		if( chk_find_chr( pty->mbr[i], p ) ){
-
 			/* ȯޥåסե饰ΩƤ */
 			p->flg_map |= FLG_MAP_CHR_FIND;
 			flg = FLG_MAP_CHR_FIND;
@@ -1518,6 +1516,7 @@ void	set_flg_work_find_mbr( mnstr_t *p, bool_t flg )
 			chk_boss_find_mbr( p );
 
 		p->work.flg |= FLG_WORK_FIND_MBR;
+		set_flg_mnstr_find_mbr( TRUE );
 	} else {
 		p->work.flg &= ~(FLG_WORK_FIND_MBR);
 	}
@@ -1532,13 +1531,11 @@ void	chk_boss_find_mbr( mnstr_t *p )
 {
 	if( p == NULL )
 		return;
-	if( p->kind != CHR_KIND_MNSTR )
-		return;
-	if( p->mnstr_tab == NULL )
-		return;
-	if( !(p->mnstr_tab->flg_boss) )
+	if( !is_boss( p ) )
 		return;
 
+	set_flg_boss_find_mbr( TRUE );
+
 	curs_attrset_chr( p, +1, TRUE );
 	print_msg( FLG_NULL, MSG_BOSS_FIND_MBR, p->name );
 	curs_attrset_dflt();
@@ -1593,11 +1590,29 @@ void	die_mnstr( mnstr_t *p )
 {
 	if( p == NULL )
 		return;
+	if( p->kind != CHR_KIND_MNSTR )
+		return;
 
 	if( is_pet( p ) ){
 		die_pet( p );
 		return;
 	}
+
+	if( is_xx( p ) ){
+		call_game_sound_play(
+				SOUND_KIND_FIGHT_DIE_MONSTER_BOSS_LAST,
+				1 );
+	} else if( p->mnstr_kind == MNSTR_KIND_XEX ){
+		;
+	} else if( is_boss( p ) ){
+		call_game_sound_play(
+				SOUND_KIND_FIGHT_DIE_MONSTER_BOSS,
+				1 );
+	} else {
+		call_game_sound_play(
+				SOUND_KIND_FIGHT_DIE_MONSTER,
+				1 );
+	}
 }
 
 /***************************************************************
@@ -1607,6 +1622,22 @@ void	die_mnstr( mnstr_t *p )
 ***************************************************************/
 
 bool_t	chk_die_boss( mnstr_t *p )
+{
+	if( !is_boss( p ) )
+		return FALSE;
+
+	die_boss( p );
+
+	return TRUE;
+}
+
+/***************************************************************
+* 󥹥ܥĴ٤
+* mnstr_t *p : 󥹥
+* return : ܥ?
+***************************************************************/
+
+bool_t	is_boss( mnstr_t *p )
 {
 	if( p == NULL )
 		return FALSE;
@@ -1617,7 +1648,51 @@ bool_t	chk_die_boss( mnstr_t *p )
 	if( !(p->mnstr_tab->flg_boss) )
 		return FALSE;
 
-	die_boss( p );
+	return TRUE;
+}
+
+/***************************************************************
+* 󥹥饹ܥĴ٤
+* mnstr_t *p : 󥹥
+* return : 饹ܥ?
+***************************************************************/
+
+bool_t	is_last_boss( mnstr_t *p )
+{
+	mnstr_t	*boss;
+	long	i;
+
+	if( p == NULL )
+		return FALSE;
+	if( p->kind != CHR_KIND_MNSTR )
+		return FALSE;
+
+	for( i = LAST_BOSS_KIND_NULL; i < LAST_BOSS_KIND_MAX_N; i++ ){
+		boss = get_last_boss( (last_boss_kind_t)i );
+		if( boss == NULL )
+			continue;
+
+		if( p->mnstr_kind == boss->mnstr_kind )
+			return TRUE;
+	}
+
+	return FALSE;
+}
+
+/***************************************************************
+* 󥹥 XX Ĵ٤
+* mnstr_t *p : 󥹥
+* return : XX ?
+***************************************************************/
+
+bool_t	is_xx( mnstr_t *p )
+{
+	if( p == NULL )
+		return FALSE;
+	if( p->kind != CHR_KIND_MNSTR )
+		return FALSE;
+	if( p->mnstr_kind != MNSTR_KIND_XX )
+		return FALSE;
 
 	return TRUE;
 }
